@@ -29,7 +29,7 @@
  **/
 
 /** @file STK_IMixtureManager.h
- *  @brief In this file we define the Interface IMixtureManager class.
+ *  @brief In this file we define the Interface class IMixtureManager
  **/
 
 
@@ -55,23 +55,32 @@ namespace STK
  *  - It allows also to set parameters to a specific mixture,
  *  - all data set are enclosed in a DataBridge structure and stored in vector v_data_
  *
- *  The pure virtual method to implement in derived classes are
+ *  The pseudo pure virtual method to implement in derived classes are
  *  @code
- *    virtual void getParameters(IMixture* p_mixture, ArrayXX& data) const =0;
- *    virtual void setParameters(IMixture* p_mixture, ArrayXX const& data) const =0;
- *    virtual IMixture* createMixtureImpl(String const& modelName, String const& idData, int nbCluster) =0;
+ *    void getMissingValuesImpl(
+ *    void getParametersImpl(IMixture* p_mixture, ArrayXX& data) const;
+ *    void setParametersImpl(IMixture* p_mixture, ArrayXX const& data) const;
+ *    IMixture* createMixtureImpl(String const& modelName, String const& idData, int nbCluster);
  *  @endcode
  *
  *  @tparam DataHandler any concrete class from the interface STK::DataHandlerBase
  */
-template<class DataHandler>
-class IMixtureManager
+template<class Derived>
+class IMixtureManager: public IRecursiveTemplate<Derived>
 {
   public:
+    typedef typename hidden::MixtureManagerTraits< Derived >::DataHandler DataHandler;
+    typedef typename hidden::MixtureManagerTraits< Derived >::Type Type;
+    typedef typename hidden::MixtureManagerTraits< Derived >::MissingIndexes MissingIndexes;
+    typedef typename hidden::MixtureManagerTraits< Derived >::MissingValues MissingValues;
+    typedef typename hidden::MixtureManagerTraits< Derived >::Data Data;
+    typedef typename hidden::MixtureManagerTraits< Derived >::DataBridgeType DataBridgeType;
+
     /** Default constructor, need an instance of a DataHandler. */
     IMixtureManager(DataHandler const* const p_handler);
     /** destructor */
-    virtual ~IMixtureManager();
+    ~IMixtureManager();
+
     /** @return constant pointer on the data handler */
     DataHandler const* const p_handler() const { return p_handler_;}
 
@@ -85,10 +94,11 @@ class IMixtureManager
      *  @return the idModel name
      **/
     String getIdModelName( String const& idData) const;
+
     /** @brief create a mixture and initialize it.
      *  This method get the modelName from the DataHandler and then delegate
-     *  the concrete creation to derived class using the pure virtual method
-     *   @c createMixtureImpl.
+     *  the concrete creation to derived class using the pseudo pure virtual method
+     *   @c createMixture( modelName, idData, nbCluster).
      *  @param idData name of the model
      *  @param nbCluster number of cluster of the model
      *  @return 0 if the idData is not find, the result of
@@ -96,7 +106,7 @@ class IMixtureManager
      **/
     IMixture* createMixture(String const& idData, int nbCluster);
     /** @brief register a data bridge to the IMixtureManager.
-     *  For each mixture created and registered, a data manager is created
+     *  For each mixture created and registered, a data bridge is created
      *  and registered so that it will be deleted when the mixture itself is
      *  deleted.
      *  @param p_data a pointer on the data manager
@@ -107,24 +117,31 @@ class IMixtureManager
      **/
     void releaseDataBridge(String const& idData);
 
-    // pure virtual methods
-    /** get the parameters from an IMixture.
-     *  @param p_mixture pointer on the mixture
-     *  @param data the array to return with the parameters
-     **/
-    virtual void getParameters(IMixture* p_mixture, ArrayXX& data) const =0;
-    /** set the parameters from an IMixture.
-     *  @param p_mixture pointer on the mixture
-     *  @param data the array with the parameters to set
-     **/
-    virtual void setParameters(IMixture* p_mixture, ArrayXX const& data) const =0;
-
     /** get the wrapper for any kind of data set using its Id
      *  @param idData Id name of the data set attached to the mixture
      *  @return a constant reference on the array with the data set
      **/
-    template<typename Type>
-    typename hidden::DataHandlerTraits<DataHandler, Type>::Data const& getData( String const& idData) const;
+    Data const& getData( String const& idData) const;
+
+    // pure virtual methods
+    /** get the missing values
+     *  @param p_mixture pointer on the mixture
+     *  @param missing array with the indexes and the missing values
+     **/
+    inline void getMissingValues(IMixture* p_mixture, MissingValues& missing) const
+    {this->asDerived().getMissingValuesImpl(p_mixture, missing);}
+    /** get the parameters from an IMixture.
+     *  @param p_mixture pointer on the mixture
+     *  @param data the array to return with the parameters
+     **/
+    inline void getParameters(IMixture* p_mixture, ArrayXX& data) const
+    { this->asDerived().getParametersImpl(p_mixture, data);}
+    /** set the parameters from an IMixture.
+     *  @param p_mixture pointer on the mixture
+     *  @param data the array with the parameters to set
+     **/
+    inline void setParameters(IMixture* p_mixture, ArrayXX const& data) const
+    { this->asDerived().setParametersImpl(p_mixture, data);}
 
   protected:
     /** Utility lookup function allowing to find a DataBridge from its idData
@@ -134,25 +151,27 @@ class IMixtureManager
     IDataBridge* getDataBridge( String const& idData) const;
 
   private:
-    /** create a concrete mixture and initialize it.
-     *  @param modelName, idData strings with the Id name of the model and of the data
-     *  @param nbCluster number of cluster of the model
-     **/
-    virtual IMixture* createMixtureImpl(String const& modelName, String const& idData, int nbCluster) =0;
     /** A pointer on the concrete instance of the data handler */
     DataHandler const* const p_handler_;
     /** vector of pointers to the data components */
     std::vector<IDataBridge*> v_data_;
+
+    /** create a concrete mixture and initialize it.
+     *  @param modelName, idData strings with the Id name of the model and of the data
+     *  @param nbCluster number of cluster of the model
+     **/
+    inline IMixture* createMixture(String const& modelName, String const& idData, int nbCluster)
+    { return this->asDerived().createMixtureImpl(modelName, idData, nbCluster);}
 };
 
 /* Utility function allowing to find the idModel from the idData
  *  @param idData the id name of the data we want the idModel
  *  @return the idModel
  **/
-template<class DataHandler>
-Clust::Mixture IMixtureManager<DataHandler>::getIdModel( String const& idData) const
+template<class Derived>
+Clust::Mixture IMixtureManager<Derived>::getIdModel( String const& idData) const
 {
-  std::string modelName;
+  String modelName;
   if (!p_handler()->getIdModelName( idData, modelName))
   {
 #ifdef STK_MIXTURE_VERY_VERBOSE
@@ -168,13 +187,13 @@ Clust::Mixture IMixtureManager<DataHandler>::getIdModel( String const& idData) c
 }
 
 /* Default constructor, need an instance of a DataHandler.  */
-template<class DataHandler>
-IMixtureManager<DataHandler>::IMixtureManager( DataHandler const* const p_handler)
-                                             : p_handler_(p_handler)
+template<class Derived>
+IMixtureManager<Derived>::IMixtureManager( DataHandler const* const p_handler)
+                                         : p_handler_(p_handler)
 {}
 /* destructor */
-template<class DataHandler>
-IMixtureManager<DataHandler>::~IMixtureManager()
+template<class Derived>
+IMixtureManager<Derived>::~IMixtureManager()
 {
   typedef std::vector<IDataBridge*>::iterator DataIterator;
   for (DataIterator it = v_data_.begin() ; it != v_data_.end(); ++it)
@@ -184,10 +203,10 @@ IMixtureManager<DataHandler>::~IMixtureManager()
  *  @param idData the id name of the data we want the idModel
  *  @return the idModel name
  **/
-template<class DataHandler>
-String IMixtureManager<DataHandler>::getIdModelName( String const& idData) const
+template<class Derived>
+String IMixtureManager<Derived>::getIdModelName( String const& idData) const
 {
-  std::string modelName;
+  String modelName;
   if (!p_handler_->getIdModelName( idData, modelName))
   {
 #ifdef STK_MIXTURE_VERY_VERBOSE
@@ -200,18 +219,19 @@ String IMixtureManager<DataHandler>::getIdModelName( String const& idData) const
 #endif
   return modelName;
 }
+
 /* create a mixture and initialize it.
  *  @param idData name of the model
  *  @param nbCluster number of cluster of the model
  *  @return 0 if the idData is not find, the result of @c createMixture( idModel, idData, nbCluster)
  *  otherwise.
  **/
-template<class DataHandler>
-IMixture* IMixtureManager<DataHandler>::createMixture(String const& idData, int nbCluster)
+template<class Derived>
+IMixture* IMixtureManager<Derived>::createMixture(String const& idData, int nbCluster)
 {
-  std::string modelName;
+  String modelName;
   if (!p_handler_->getIdModelName( idData, modelName)) { return 0;};
-  return createMixtureImpl( modelName, idData, nbCluster);
+  return createMixture( modelName, idData, nbCluster);
 }
 /* @brief register a data manager to the IMixtureManager.
  *  For each mixture created and registered, a data manager is created
@@ -219,14 +239,14 @@ IMixture* IMixtureManager<DataHandler>::createMixture(String const& idData, int
  *  deleted.
  *  @param p_data a pointer on the data manager
  **/
-template<class DataHandler>
-void IMixtureManager<DataHandler>::registerDataBridge(IDataBridge* p_data)
+template<class Derived>
+void IMixtureManager<Derived>::registerDataBridge(IDataBridge* p_data)
 { v_data_.push_back(p_data);}
 /* release a data set from v_data_.
  *  @param idData name of the data set to release
  **/
-template<class DataHandler>
-void IMixtureManager<DataHandler>::releaseDataBridge(String const& idData)
+template<class Derived>
+void IMixtureManager<Derived>::releaseDataBridge(String const& idData)
 {
   typedef std::vector<IDataBridge*>::iterator DataIterator;
   for (DataIterator it = v_data_.begin(); it != v_data_.end(); ++it)
@@ -237,8 +257,8 @@ void IMixtureManager<DataHandler>::releaseDataBridge(String const& idData)
  *  @param idData the id name of the mixture we want to get
  *  @return a pointer on the DataBridge
  **/
-template<class DataHandler>
-IDataBridge* IMixtureManager<DataHandler>::getDataBridge( String const& idData) const
+template<class Derived>
+IDataBridge* IMixtureManager<Derived>::getDataBridge( String const& idData) const
 {
   typedef std::vector<IDataBridge*>::const_iterator ConstDataIterator;
   for (ConstDataIterator it = v_data_.begin(); it != v_data_.end(); ++it)
@@ -250,14 +270,16 @@ IDataBridge* IMixtureManager<DataHandler>::getDataBridge( String const& idData)
  *  @param idData Id name of the data set attached to the mixture
  *  @return a constant reference on the array with the data set
  **/
-template<class DataHandler>
-template<typename Type>
-typename hidden::DataHandlerTraits<DataHandler, Type>::Data const& IMixtureManager<DataHandler>::getData( String const& idData) const
+template<class Derived>
+typename hidden::MixtureManagerTraits< Derived >::Data const& IMixtureManager<Derived>::getData( String const& idData) const
 {
-  typedef typename hidden::DataHandlerTraits<DataHandler, Type>::Data DataType;
-  typedef DataBridge<DataType> DataBridgeType;
-  return static_cast<DataBridgeType*>(getDataBridge(idData))->dataij();
+  IDataBridge* p_bridge = getDataBridge(idData);
+  if (p_bridge)
+    return static_cast<DataBridgeType*>(p_bridge)->dataij();
+  else
+    STKRUNTIME_ERROR_1ARG(IMixtureManager::getData,idData,data bridge does not exist);
 }
+
 } // namespace STK
 
 
